import { Component, OnInit, ViewChild } from '@angular/core';
import { NzTreeNode } from "ng-zorro-antd";
import { SystemService } from "../system.service";
import {UserComponent} from '../modal/user/user.component';
import {GroupModalComponent} from '../modal/group-modal/group-modal.component';

@Component({
  selector: 'jhi-group',
  templateUrl: './group.component.html',
  styles: []
})
export class GroupComponent implements OnInit {

    @ViewChild('power') power;
    @ViewChild('smartUser') smartUser:UserComponent;
    @ViewChild('smartGroupModal') smartGroupModal:GroupModalComponent;

    dataSet:any[];
    groupList:any[];
    allChecked = false;
    disabledButton = true;
    indeterminate = false;
    checkedNumber = 0;
    nodes: any[];
    isVisible = true;
    displayData: Array<{ key1: string; key2: number; key3: string; key4: string; checked:boolean }> = [];
  constructor(private systemSer: SystemService) { }

    checkAll(value: boolean): void {
        this.displayData.forEach(data => data.checked = value);
        this.refreshStatus();
    }

    currentPageDataChange($event: Array<{ key1: string; key2: number; key3: string; key4: string; checked:boolean  }>): void {
        this.displayData = $event;
    }

    refreshStatus(): void {
        const allChecked = this.displayData.every(value => value.checked === true);
        const allUnChecked = this.displayData.every(value => !value.checked);
        this.allChecked = allChecked;
        this.indeterminate = (!allChecked) && (!allUnChecked);
        this.disabledButton = !this.dataSet.some(value => value.checked);
        this.checkedNumber = this.dataSet.filter(value => value.checked).length;
    }

    // expandKeys = [ '1001', '10001' ];

    mouseAction(name: string, e: any): void {
        console.log(name, e);
    }

    ngOnInit() {
      this.getUser();
      this.getGroup();
    }

    getUser(){
        const data = {
            'name': '',
            'orgId': '',
            'pageNumber':'',
            'pageSize':''
        }
        this.systemSer.user(data).subscribe(
            (res)=>{
                this.dataSet = res.data;
            }
        )
    }

    //组织信息
    getGroup(){
        this.systemSer.organization().subscribe(
            (res)=>{
                this.groupList = res.data;
                res.data.forEach(res=>{
                    res.title = res.name;
                    res.key = res.id;
                    this.nodes = [
                      new NzTreeNode(res)
                    ];
                });
            }
        )
    }

    showModal(): void {
        this.isVisible = true;
    }

    handleOk(): void {
        this.isVisible = false;
    }

    handleCancel(): void {
        this.isVisible = false;
    }

    selectJ(){
      this.power.hello();
    }

    //新增用户
    showUserModal(){
      this.smartUser.showModal();
    }

    //新增部门
    showGroupModal(){
      this.smartGroupModal.showModal(this.groupList);
    }

}
